elephant.spike\_train\_generation.single\_interaction\_process
==============================================================

.. currentmodule:: elephant.spike_train_generation

.. autofunction:: single_interaction_process